@@ -14,7 +14,7 @@
 #include "katebookmarkhandler.h"
 #include "katefileactions.h"
 
-#include <ktexteditor/document.h>
+#include <KTextEditor/Document>
 #include <ktexteditor/view.h>
 
 #include <KActionCollection>
@@ -28,7 +28,6 @@
 #include <KSharedConfig>
 #include <KToolBar>
 #include <KUrlNavigator>
-#include <kwidgetsaddons_version.h>
 
 #include <QAbstractItemView>
 #include <QAction>
@@ -149,7 +148,7 @@ void KateFileBrowser::setupToolbar()
     m_toolbar->clear();
 
     // now add all actions to the toolbar
-    for (const QString &it : qAsConst(actions)) {
+    for (const QString &it : std::as_const(actions)) {
         QAction *ac = nullptr;
         if (it.isEmpty()) {
             continue;
